@@ -58,7 +58,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "not_null":
             for i in range(0, 200):
                 name = get_random_string(6)
@@ -120,7 +120,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "is_null":
             for i in range(0, 200):
                 name = get_random_string(6)
@@ -181,7 +181,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "is_date":
             for i in range(0, 200):
                 name = get_random_string(6)
@@ -205,7 +205,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "is_not_date":
             for i in range(0, 200):
                 name = get_random_string(6)
@@ -224,7 +224,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "is_number":
             for i in range(0, 200):
                 name = get_random_string(6)
@@ -263,7 +263,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
         elif usecase == "is_not_number":
             for i in range(0, 200):
                 name = get_random_string(5)
@@ -288,7 +288,7 @@ def create_training_data():
                     df1 = pd.DataFrame({"Sentences": [Sentence], "UseCase": [UseCase]})
                     if len(df.dropna()) == 0:
                         df = df1
-                    df = df.append(df1, ignore_index=True)
+                    df = pd.concat([df, df1])
     b_size_df = len(df)
     df.sort_values("Sentences", inplace=True)
     df.drop_duplicates(subset="Sentences", keep=False, inplace=True)
